YkActionManager class

行为管理器,支持 code 和 inApp 两种行为注册与执行

Properties

hashCode int
The hash code for this object.
no setterinherited
onError ExecuteError?
no getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeAction(String action, dynamic actionContent) Future
执行 code 行为
executeInAppAction(String globalType, String funcType, dynamic data) Future
执行 inApp 行为
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCodeAction(String code, CodeClosure closure) → void
注册 code 行为
registerInAppAction(String globalType, String funcType, InAppClosure inAppClosure) → void
注册 inApp 行为
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance YkActionManager
final

Constants

ykAmDataKey → const String
ykAmFuncKey → const String
ykAmGlobalKey → const String