YkCoreInfo class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConfig() Future
getCoreToken({bool needShowLogin = false}) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

bgWhiteColor Color
getter/setter pair
emptyWidget Widget
getter/setter pair
instance YkCoreInfo
final
loadingWidget Widget
getter/setter pair
mainColor Color
getter/setter pair
textColor Color
getter/setter pair