YkDigLogUtil class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance YkDigLogUtil
final
maxFileSize int
getter/setter pair

Static Methods

addLog({required String event, required String title, required dynamic params}) → void
archiveAndUpload() Future<void>
setup({required YkDigLogUtilDelegate delegate}) Future<void>