YkDigLogUtilDelegate class

Constructors

YkDigLogUtilDelegate({required Future<void> setup(), required Future<bool> uploadCallBack(String data), required Future<String> saveDocumentPath(), Future<String> handleData(String event, String title, dynamic params)?, void logCallBack(dynamic data)?})
const

Properties

handleData Future<String> Function(String event, String title, dynamic params)?
final
hashCode int
The hash code for this object.
no setterinherited
logCallBack → void Function(dynamic data)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveDocumentPath Future<String> Function()
final
setup Future<void> Function()
final
uploadCallBack Future<bool> Function(String data)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited