YkFileManager class

文件管理工具类

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createPath({required String path}) Future<bool>
创建目录
deleteFile({required String path}) Future<bool>
删除文件
exists({required String path}) Future<bool>
检查文件是否存在
getData({required String path}) Future<List<int>?>
读取文件数据
getDocumentPath() Future<String>
获取应用程序文档目录路径
save({required List<int> bytes, required String filePath}) Future<bool>
保存文件