YkPermission class

Constructors

YkPermission()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

check({required YkPermissionType type, bool requestIfDenied = true, Future<bool> onDenied(Future<bool> openSetting())?}) Future<bool>
检查并请求权限 type 权限类型 requestIfDenied 是否在未授权时自动请求 onDenied 拒绝时的回调,参数为打开设置页的方法